@@ -1,4 +1,3 @@
-/* vim: set sw=8 ts=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /**
  * excel.h: Excel support interface to gnumeric
  *
@@ -12,7 +11,7 @@
 #ifndef GNM_MS_EXCEL_H
 #define GNM_MS_EXCEL_H
 
-#include "gnumeric.h"
+#include <gnumeric.h>
 #include "ms-biff.h"
 
 void excel_read_workbook (GOIOContext *context, WorkbookView *new_wb,
