@@ -1,4 +1,3 @@
-/* vim: set sw=8 ts=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /**
  * ms-excel-xf.h: MS Excel support for Gnumeric
  *
@@ -12,9 +11,9 @@
 #ifndef GNM_MS_EXCEL_XF_H
 #define GNM_MS_EXCEL_XF_H
 
-#include "style.h"
-#include "style-border.h"
-#include "style-color.h"
+#include <style.h>
+#include <style-border.h>
+#include <style-color.h>
 
 #define STYLE_TOP		(MSTYLE_BORDER_TOP	    - MSTYLE_BORDER_TOP)
 #define STYLE_BOTTOM		(MSTYLE_BORDER_BOTTOM	    - MSTYLE_BORDER_TOP)
