@@ -1,7 +1,7 @@
 #ifndef GNUMERIC_GLPK_BOOT_H
 #define GNUMERIC_GLPK_BOOT_H
 
-#include "gnumeric.h"
+#include <gnumeric.h>
 #include <goffice/goffice.h>
 #include <gsf/gsf-output.h>
 #include <tools/gnm-solver.h>
