@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * pln.c: read sheets using a Plan Perfect encoding.
  *
@@ -154,7 +153,7 @@ static guint8 const signature[] =
     { 0xff, 'W','P','C', 0x10, 0, 0, 0, 0x9, 0xa };
 
 /* in charset.c. */
-guint8 *pln_get_str (guint8 const *ch, int len);
+guint8 *pln_get_str (guint8 const *ch, unsigned len);
 
 static char const *
 pln_get_func_table1 (unsigned i)
