@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * dao-gui-utils.c:
@@ -21,20 +20,19 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "dao-gui-utils.h"
+#include <dialogs/dao-gui-utils.h>
 
-#include "value.h"
-#include "gui-util.h"
-#include "selection.h"
+#include <value.h>
+#include <gui-util.h>
+#include <selection.h>
 #include <widgets/gnm-dao.h>
+#include <dialogs/tool-dialogs.h>
 
-#include <gtk/gtk.h>
 
 /**
  * dialog__tool_preset_to_range:
@@ -45,7 +43,7 @@
  **/
 
 void
-dialog_tool_preset_to_range (GenericToolState *state)
+dialog_tool_preset_to_range (GnmGenericToolState *state)
 {
 	GnmRange const *sel;
 	GtkWidget *w;
@@ -64,7 +62,7 @@ dialog_tool_preset_to_range (GenericToolState *state)
 
 
 /**
- * dialog_tool_init_outputs:
+ * dialog_tool_init_outputs: (skip)
  * @state:
  * @sensitivity_cb:
  *
@@ -72,7 +70,7 @@ dialog_tool_preset_to_range (GenericToolState *state)
  *
  **/
 void
-dialog_tool_init_outputs (GenericToolState *state, GCallback sensitivity_cb)
+dialog_tool_init_outputs (GnmGenericToolState *state, GCallback sensitivity_cb)
 {
 	GtkWidget *dao_box;
 
@@ -92,20 +90,17 @@ dialog_tool_init_outputs (GenericToolState *state, GCallback sensitivity_cb)
 				G_CALLBACK (sensitivity_cb), state);
 	gnm_editable_enters (GTK_WINDOW (state->dialog),
 				  GTK_WIDGET (state->gdao));
-
-	return;
 }
 
 /**
- * parse_output:
- *
+ * parse_output: (skip)
  * @state:
  * @dao:
  *
  * fill dao with information from the standard output section of a dialog
  */
 data_analysis_output_t *
-parse_output (GenericToolState *state, data_analysis_output_t *dao)
+parse_output (GnmGenericToolState *state, data_analysis_output_t *dao)
 {
 	data_analysis_output_t *this_dao = dao;
 
