@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-analysis-tool-principal-components.c:
  *
@@ -18,16 +17,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "analysis-principal-components.h"
-#include "analysis-tools.h"
+#include <dialogs/dialogs.h>
+#include <tools/analysis-principal-components.h>
+#include <tools/analysis-tools.h>
 
 #include <workbook.h>
 #include <workbook-control.h>
@@ -36,8 +34,8 @@
 #include <gui-util.h>
 #include <parse-util.h>
 #include <gnm-format.h>
-#include <tool-dialogs.h>
-#include <dao-gui-utils.h>
+#include <dialogs/tool-dialogs.h>
+#include <dialogs/dao-gui-utils.h>
 #include <sheet.h>
 #include <expr.h>
 #include <number-match.h>
@@ -45,13 +43,12 @@
 #include <selection.h>
 #include <value.h>
 #include <commands.h>
-#include "help.h"
+#include <dialogs/help.h>
 
 #include <widgets/gnm-dao.h>
-#include <widgets/gnumeric-expr-entry.h>
+#include <widgets/gnm-expr-entry.h>
 
 #include <string.h>
-#include <gtk/gtk.h>
 
 #define PRINCIPAL_COMPONENTS_KEY "analysistools-principal-components-dialog"
 
@@ -64,7 +61,7 @@ static char const * const grouped_by_group[] = {
 
 static void
 principal_components_tool_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
-						 GenericToolState *state)
+						 GnmGenericToolState *state)
 {
         GSList *input_range;
 
@@ -102,7 +99,7 @@ principal_components_tool_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
  **/
 static void
 principal_components_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
-			GenericToolState *state)
+			GnmGenericToolState *state)
 {
 	data_analysis_output_t  *dao;
 	analysis_tools_data_generic_t  *data;
@@ -129,7 +126,7 @@ principal_components_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 		char   *text;
 		text = g_strdup_printf (
 			_("An unexpected error has occurred."));
-		error_in_entry ((GenericToolState *) state,
+		error_in_entry ((GnmGenericToolState *) state,
 				GTK_WIDGET (state->input_entry), text);
 		g_free (text);
 	} else
@@ -150,7 +147,7 @@ principal_components_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 int
 dialog_principal_components_tool (WBCGtk *wbcg, Sheet *sheet)
 {
-        GenericToolState *state;
+        GnmGenericToolState *state;
 	char const * plugins[] = { "Gnumeric_fnstat",
 				   "Gnumeric_fnmath",
 				   "Gnumeric_fnlogical",
@@ -164,11 +161,11 @@ dialog_principal_components_tool (WBCGtk *wbcg, Sheet *sheet)
 	if (gnm_dialog_raise_if_exists (wbcg, PRINCIPAL_COMPONENTS_KEY))
 		return 0;
 
-	state = g_new0 (GenericToolState, 1);
+	state = g_new0 (GnmGenericToolState, 1);
 
 	if (dialog_tool_init (state, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_PRINCIPAL_COMPONENTS,
-			      "principal-components.ui", "PrincipalComponents",
+			      "res:ui/principal-components.ui", "PrincipalComponents",
 			      _("Could not create the Principal Components Analysis Tool dialog."),
 			      PRINCIPAL_COMPONENTS_KEY,
 			      G_CALLBACK (principal_components_tool_ok_clicked_cb), NULL,
@@ -178,7 +175,7 @@ dialog_principal_components_tool (WBCGtk *wbcg, Sheet *sheet)
 
 	gnm_dao_set_put (GNM_DAO (state->gdao), TRUE, TRUE);
 	principal_components_tool_update_sensitivity_cb (NULL, state);
-	tool_load_selection ((GenericToolState *)state, TRUE);
+	tool_load_selection ((GnmGenericToolState *)state, TRUE);
 
         return 0;
 }
