@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-stf-export.c : implementation of the STF export dialog
  *
@@ -16,13 +15,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <gnumeric.h>
-#include "dialog-stf-export.h"
+#include <dialogs/dialog-stf-export.h>
 
 #include <command-context.h>
 #include <workbook.h>
@@ -33,7 +31,6 @@
 #include <gnumeric-conf.h>
 #include <goffice/goffice.h>
 
-#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
@@ -427,7 +424,7 @@ cb_sheet_select_none (TextExportState *state)
 	set_sheet_selection_count (state, 0);
 }
 
-/**
+/*
  * Refreshes the buttons on a row (un)selection and selects the chosen sheet
  * for this view.
  */
@@ -696,13 +693,14 @@ cb_next_page (TextExportState *state)
 }
 
 /**
- * stf_dialog
- * @wbcg: #WBCGtk (can be NULL)
+ * stf_export_dialog:
+ * @wbcg: (nullable): #WBCGtk
  * @stfe: An exporter to set up (and take defaults from)
  * @wb: The #Workbook to export
  *
  * This will start the export assistant.
- * returns : TRUE if cancelled.
+ *
+ * Returns: %TRUE if cancelled.
  **/
 gboolean
 stf_export_dialog (WBCGtk *wbcg, GnmStfExport *stfe, Workbook *wb)
@@ -712,7 +710,7 @@ stf_export_dialog (WBCGtk *wbcg, GnmStfExport *stfe, Workbook *wb)
 	g_return_val_if_fail (GNM_IS_WORKBOOK (wb), TRUE);
 	g_return_val_if_fail (GNM_IS_STF_EXPORT (stfe), TRUE);
 
-	state.gui = gnm_gtk_builder_load ("dialog-stf-export.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	state.gui = gnm_gtk_builder_load ("res:ui/dialog-stf-export.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (state.gui == NULL)
 		return TRUE;
 
