@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-data-slicer.h :
  *
@@ -22,7 +21,7 @@
 #ifndef GO_DATA_SLICER_H
 #define GO_DATA_SLICER_H
 
-#include "goffice-data.h"	/* remove after move to goffice */
+#include <goffice-data.h>	/* remove after move to goffice */
 #include <glib-object.h>
 
 G_BEGIN_DECLS
