@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * print.c: Printing routines for Gnumeric
@@ -14,36 +13,35 @@
  * Handles printing of Sheets.
  */
 #include <gnumeric-config.h>
-#include "print-cell.h"
+#include <print-cell.h>
 
-#include "gnumeric.h"
-#include "print.h"
+#include <gnumeric.h>
+#include <print.h>
 
-#include "gui-util.h"
-#include "gutils.h"
-#include "sheet-object.h"
-#include "sheet-object-impl.h"
-#include "selection.h"
-#include "workbook.h"
-#include "workbook-control.h"
-#include "wbc-gtk.h"
-#include "command-context.h"
-#include "dialogs.h"
-#include "gnumeric-conf.h"
-#include "libgnumeric.h"
-#include "sheet.h"
-#include "value.h"
-#include "cellspan.h"
-#include "print-info.h"
-#include "application.h"
-#include "sheet-style.h"
-#include "ranges.h"
-#include "parse-util.h"
-#include "style-font.h"
-#include "gnumeric-conf.h"
+#include <gui-util.h>
+#include <gutils.h>
+#include <sheet-object.h>
+#include <sheet-object-impl.h>
+#include <selection.h>
+#include <workbook.h>
+#include <workbook-control.h>
+#include <wbc-gtk.h>
+#include <command-context.h>
+#include <dialogs/dialogs.h>
+#include <gnumeric-conf.h>
+#include <libgnumeric.h>
+#include <sheet.h>
+#include <value.h>
+#include <cellspan.h>
+#include <print-info.h>
+#include <application.h>
+#include <sheet-style.h>
+#include <ranges.h>
+#include <parse-util.h>
+#include <style-font.h>
+#include <gnumeric-conf.h>
 #include <goffice/goffice.h>
 
-#include <gtk/gtk.h>
 #include <gsf/gsf-meta-names.h>
 
 #include <glib/gi18n-lib.h>
@@ -221,22 +219,37 @@ gnm_print_sheet_objects (cairo_t *cr,
 		/* move to top left */
 		if (sheet->text_is_rtl) {
 			double tr_x, tr_y;
-			tr_x =  base_x - 0.5 /* because of leading gridline */
-				- sheet_col_get_distance_pts (sheet, 0, r->end.col+1)
-				+ sheet_col_get_distance_pts (sheet, 0,
-							      range->start.col);
-			tr_y =  base_y + 0.5
-				+ sheet_row_get_distance_pts (sheet, 0, r->start.row)
-				- sheet_row_get_distance_pts (sheet, 0,
-							      range->start.row);
+			switch (so->anchor.mode) {
+			case GNM_SO_ANCHOR_ABSOLUTE:
+				tr_x = base_x - 0.5; /* because of leading gridline */
+				tr_y = base_y + 0.5;
+				break;
+			case GNM_SO_ANCHOR_ONE_CELL:
+				tr_x = base_x - 0.5
+					- sheet_col_get_distance_pts (sheet, 0, r->start.col+1)
+					+ sheet_col_get_distance_pts (sheet, 0, range->start.col);
+				tr_y = base_y + 0.5
+					+ sheet_row_get_distance_pts (sheet, 0, r->start.row)
+					- sheet_row_get_distance_pts (sheet, 0, range->start.row);
+				break;
+			default:
+				tr_x = base_x - 0.5
+					- sheet_col_get_distance_pts (sheet, 0, r->end.col+1)
+					+ sheet_col_get_distance_pts (sheet, 0, range->start.col);
+				tr_y = base_y + 0.5
+					+ sheet_row_get_distance_pts (sheet, 0, r->start.row)
+					- sheet_row_get_distance_pts (sheet, 0, range->start.row);
+				break;
+			}
 			cairo_translate (cr, tr_x, tr_y);
 		} else
-			cairo_translate (cr,
-					 base_x + 0.5
+			cairo_translate (cr, (so->anchor.mode == GNM_SO_ANCHOR_ABSOLUTE)?
+					 base_x + 0.5: base_x + 0.5
 					 + sheet_col_get_distance_pts (sheet, 0, r->start.col)
 					 - sheet_col_get_distance_pts (sheet, 0,
 								       range->start.col),
-					 base_y + 0.5
+			         (so->anchor.mode == GNM_SO_ANCHOR_ABSOLUTE)?
+					 base_y + 0.5: base_y + 0.5
 					 + sheet_row_get_distance_pts (sheet, 0, r->start.row)
 					 - sheet_row_get_distance_pts (sheet, 0,
 								       range->start.row));
@@ -1789,7 +1802,7 @@ gnm_print_sheet (WorkbookControl *wbc, Sheet *sheet,
 	gtk_print_settings_set_use_color (settings,
 					  !sheet->print_info->print_black_and_white);
 	if (!export_dst && !preview_via_pdf && !preview) {
-		/* We should be setting the output file name to somethig */
+		/* We should be setting the output file name to something */
 		/* reasonable */
 		saved_uri = print_info_get_printtofile_uri (sheet->print_info);
 		if (saved_uri != NULL &&
