@@ -49,7 +49,7 @@ GType sheet_object_imageable_get_type (void);
 
 GType sheet_object_exportable_get_type (void);
 
-gboolean      sheet_object_set_sheet	 (SheetObject *so, Sheet *sheet);
+void          sheet_object_set_sheet	 (SheetObject *so, Sheet *sheet);
 Sheet	     *sheet_object_get_sheet	 (SheetObject const *so);
 void	      sheet_object_clear_sheet	 (SheetObject *so);
 
@@ -150,6 +150,7 @@ void sheet_object_draw_cairo_sized (SheetObject const *so, cairo_t *cr, double w
 
 /* management routine to register all the builtin object types */
 void sheet_objects_init (void);
+void sheet_objects_shutdown (void);
 G_END_DECLS
 
 #endif /* _GNM_SHEET_OBJECT_H_ */
