@@ -1,8 +1,8 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_SHEET_STYLE_H_
 # define _GNM_SHEET_STYLE_H_
 
-#include "gnumeric.h"
+#include <gnumeric.h>
+#include <style-border.h>
 
 G_BEGIN_DECLS
 
@@ -27,9 +27,11 @@ GnmStyle *sheet_style_find  		(Sheet const *sheet, GnmStyle *st);
 void	 sheet_style_get_row		(Sheet const *sheet, GnmStyleRow *sr);
 GnmStyle **sheet_style_get_row2		(Sheet const *sheet, int row);
 void	 sheet_style_apply_border	(Sheet *sheet, GnmRange const *range,
-					 GnmBorder **borders);
+					 GnmBorder *borders[GNM_STYLE_BORDER_EDGE_MAX]);
 void	 sheet_style_apply_range	(Sheet *sheet, GnmRange const *range,
 					 GnmStyle *pstyle);
+void	 sheet_style_apply_range2	(Sheet *sheet, GnmRange const *range,
+					 GnmStyle *pstyle);
 void	 sheet_style_set_range		(Sheet  *sheet, GnmRange const *range,
 					 GnmStyle *style);
 void	 sheet_style_apply_col		(Sheet  *sheet, int col,
@@ -41,10 +43,11 @@ void	 sheet_style_set_pos		(Sheet  *sheet, int col, int row,
 void	 sheet_style_apply_pos		(Sheet  *sheet, int col, int row,
 					 GnmStyle *style);
 
-void	 sheet_style_insert_colrow	(GnmExprRelocateInfo const *rinfo);
+void	 sheet_style_insdel_colrow	(GnmExprRelocateInfo const *rinfo);
 void	 sheet_style_relocate		(GnmExprRelocateInfo const *rinfo);
 unsigned int sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
-					 GnmStyle **style, GnmBorder **borders);
+					 GnmStyle **style,
+					 GnmBorder *borders[GNM_STYLE_BORDER_EDGE_MAX]);
 void	 sheet_style_get_extent		(Sheet const *sheet, GnmRange *r);
 void	 sheet_style_get_nondefault_extent (Sheet const *sheet, GnmRange *extent,
 					    const GnmRange *src, GnmStyle **col_defaults);
@@ -73,7 +76,7 @@ void sheet_style_shutdown (Sheet *sheet);
 void      sheet_style_set_auto_pattern_color (Sheet  *sheet,
 					      GnmColor *grid_color);
 GnmColor *sheet_style_get_auto_pattern_color (Sheet const *sheet);
-void      sheet_style_update_grid_color      (Sheet const *sheet);
+void      sheet_style_update_grid_color      (Sheet const *sheet, GtkStyleContext *context);
 
 GnmStyle const    *style_list_get_style	 (GnmStyleList const *l, int col, int row);
 void		   style_list_free	 (GnmStyleList *l);
