@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * sheet-utils.c: Utility routines for Sheet content
@@ -21,9 +20,9 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include "libgnumeric.h"
-#include "sheet-utils.h"
-#include "sheet.h"
+#include <libgnumeric.h>
+#include <sheet-utils.h>
+#include <sheet.h>
 
 static gboolean
 sheet_cell_or_one_below_is_not_empty (Sheet *sheet, int col, int row)
