@@ -20,6 +20,9 @@ struct _ColRowCollection {
 	ColRowInfo  default_style;
 	GPtrArray * info;
 	int	    max_outline_level;
+
+	// Index into @info of last ColRowSegment with valid pixel_start
+	int         last_valid_pixel_start;
 };
 
 typedef struct _SheetPrivate SheetPrivate;
@@ -49,6 +52,8 @@ struct _Sheet {
 
 	GnmSheetStyleData *style_data; /* See sheet-style.c */
 
+	GnmSheetConditionsData *conditions; // See sheet-conditions.c
+
 	ColRowCollection cols, rows;
 
 	GHashTable  *cell_hash;	/* The cells in hashed format */
@@ -182,6 +187,7 @@ GPtrArray  *sheet_cell_positions (Sheet *sheet, gboolean comments);
 GPtrArray  *sheet_cells          (Sheet *sheet, const GnmRange *r);
 
 void        sheet_recompute_spans_for_col     (Sheet *sheet, int col);
+void        sheet_range_unrender (Sheet *sheet, GnmRange const *r);
 
 gboolean    sheet_is_region_empty	      (Sheet *sheet, GnmRange const *r);
 gboolean    sheet_is_cell_empty		      (Sheet *sheet, int col, int row);
@@ -220,6 +226,9 @@ ColRowInfo const *sheet_row_get_info	  (Sheet const *sheet, int row);
 ColRowInfo const *sheet_colrow_get_info	  (Sheet const *sheet,
 					   int colrow, gboolean is_cols);
 
+void sheet_colrow_copy_info               (Sheet *sheet, int colrow,
+					   gboolean is_cols, ColRowInfo const *cri);
+
 gboolean          sheet_colrow_foreach	   (Sheet const *sheet,
 					    gboolean is_cols,
 					    int first, int last,
@@ -241,9 +250,13 @@ gboolean          sheet_colrow_foreach	   (Sheet const *sheet,
  *
  * _default == The size of all cols/rows that do not have explicit sizes.
  */
+
+gint64  sheet_colrow_get_distance_pixels (Sheet const *sheet, gboolean is_cols,
+					  int from, int to);
+
 /* Col width */
-double  sheet_col_get_distance_pts	  (Sheet const *sheet, int from_col, int to_col);
-int     sheet_col_get_distance_pixels     (Sheet const *sheet, int from_col, int to_col);
+double  sheet_col_get_distance_pts	  (Sheet const *sheet, int from, int to);
+gint64  sheet_col_get_distance_pixels     (Sheet const *sheet, int from, int to);
 void    sheet_col_set_size_pts		  (Sheet *sheet, int col, double width_pts,
 					   gboolean set_by_user);
 void    sheet_col_set_size_pixels	  (Sheet *sheet, int col, int width_pixels,
@@ -254,8 +267,8 @@ void    sheet_col_set_default_size_pts	  (Sheet *sheet, double width_pts);
 void    sheet_col_set_default_size_pixels (Sheet *sheet, int width_pixels);
 
 /* Row height */
-double  sheet_row_get_distance_pts	  (Sheet const *sheet, int from_row, int to_row);
-int     sheet_row_get_distance_pixels     (Sheet const *sheet, int from, int to);
+double  sheet_row_get_distance_pts	  (Sheet const *sheet, int from, int to);
+gint64  sheet_row_get_distance_pixels     (Sheet const *sheet, int from, int to);
 void    sheet_row_set_size_pts		  (Sheet *sheet, int row, double height_pts,
 					   gboolean set_by_user);
 void    sheet_row_set_size_pixels	  (Sheet *sheet, int row, int height_pixels,
@@ -406,6 +419,8 @@ GOUndo *sheet_clear_region_undo (GnmSheetRange *sr,
 
 SheetView *sheet_get_view (Sheet const *sheet, WorkbookView const *wbv);
 
+void sheet_freeze_object_views (Sheet const *sheet, gboolean qfreeze);
+
 GODateConventions const *sheet_date_conv (Sheet const *sheet);
 
 // Introspection support
