@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * ssindex.c: A wrapper application to index spreadsheets
  *
@@ -10,24 +9,25 @@
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n.h>
-#include "gnumeric.h"
-#include "libgnumeric.h"
-#include "gutils.h"
-#include "gnumeric-paths.h"
+#include <gnumeric.h>
+#include <libgnumeric.h>
+#include <gutils.h>
+#include <gnumeric-paths.h>
 #include <goffice/goffice.h>
-#include "command-context-stderr.h"
-#include "workbook-view.h"
-#include "workbook.h"
-#include "sheet.h"
-#include "cell.h"
-#include "expr-name.h"
-#include "value.h"
-#include "mstyle.h"
-#include "sheet-style.h"
-#include "hlink.h"
-#include "validation.h"
-#include "sheet-object-graph.h"
-#include "gnm-plugin.h"
+#include <command-context-stderr.h>
+#include <workbook-view.h>
+#include <workbook.h>
+#include <sheet.h>
+#include <cell.h>
+#include <expr-name.h>
+#include <value.h>
+#include <mstyle.h>
+#include <sheet-style.h>
+#include <hlink.h>
+#include <validation.h>
+#include <sheet-object-graph.h>
+#include <gnm-plugin.h>
+#include <gnumeric-conf.h>
 
 #include <gsf/gsf-utils.h>
 #include <gsf/gsf-libxml.h>
@@ -211,9 +211,9 @@ ssindex (char const *file, GOIOContext *ioc)
 				gsf_xml_out_simple_element (state.output,
 							    "data", str);
 				g_free (str);
-			} else if (IS_SHEET_OBJECT_GRAPH (obj))
+			} else if (GNM_IS_SO_GRAPH (obj))
 				ssindex_chart (&state,
-					       (GogObject *)sheet_object_graph_get_gog (SHEET_OBJECT (obj)));
+					       (GogObject *)sheet_object_graph_get_gog (GNM_SO (obj)));
 		}
 		g_slist_free (objs);
 
@@ -247,6 +247,8 @@ main (int argc, char const **argv)
 	/* No code before here, we need to init threads */
 	argv = gnm_pre_parse_init (argc, argv);
 
+	gnm_conf_set_persistence (FALSE);
+
 	ocontext = g_option_context_new (_("INFILE..."));
 	g_option_context_add_main_entries (ocontext, ssindex_options, GETTEXT_PACKAGE);
 	g_option_context_add_group	  (ocontext, gnm_get_option_group ());
@@ -273,7 +275,7 @@ main (int argc, char const **argv)
 
 	gnm_init ();
 
-	cc = cmd_context_stderr_new ();
+	cc = gnm_cmd_context_stderr_new ();
 	gnm_plugins_init (GO_CMD_CONTEXT (cc));
 	go_plugin_db_activate_plugin_list (
 		go_plugins_get_available_plugins (), &plugin_errs);
