@@ -1076,7 +1076,7 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 
 	case VALUE_FLOAT:
 		if (conv->output.decimal_digits < 0)
-			go_dtoa (target, "!" GNM_FORMAT_g, v->v_float.val);
+			go_dtoa (target, "!^" GNM_FORMAT_g, v->v_float.val);
 		else
 			g_string_append_printf (target, "%.*" GNM_FORMAT_g,
 						conv->output.decimal_digits,
