@@ -1,5 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
  * wbc-gtk-edit.c: Keeps track of the cell editing process.
  *
@@ -22,38 +20,37 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
+#include <gnumeric.h>
 
-#include "gnm-pane-impl.h"
-#include "wbc-gtk-impl.h"
-#include "workbook-view.h"
-#include "workbook-priv.h"
-#include "application.h"
-#include "clipboard.h"
-#include "complete-sheet.h"
-#include "commands.h"
-#include "gnumeric-conf.h"
-#include "mstyle.h"
-#include "style-color.h"
-#include "sheet-control-gui-priv.h"
-#include "sheet-style.h"
-#include "sheet-view.h"
-#include "sheet.h"
-#include "cell.h"
-#include "expr.h"
-#include "gnm-format.h"
-#include "number-match.h"
-#include "parse-util.h"
-#include "ranges.h"
-#include "selection.h"
-#include "validation.h"
-#include "value.h"
-#include "widgets/gnumeric-expr-entry.h"
-#include "gui-util.h"
-#include "command-context.h"
+#include <gnm-pane-impl.h>
+#include <wbc-gtk-impl.h>
+#include <workbook-view.h>
+#include <workbook-priv.h>
+#include <application.h>
+#include <clipboard.h>
+#include <complete-sheet.h>
+#include <commands.h>
+#include <gnumeric-conf.h>
+#include <mstyle.h>
+#include <style-color.h>
+#include <sheet-control-gui-priv.h>
+#include <sheet-style.h>
+#include <sheet-view.h>
+#include <sheet.h>
+#include <cell.h>
+#include <expr.h>
+#include <gnm-format.h>
+#include <number-match.h>
+#include <parse-util.h>
+#include <ranges.h>
+#include <selection.h>
+#include <validation.h>
+#include <value.h>
+#include <widgets/gnm-expr-entry.h>
+#include <gui-util.h>
+#include <command-context.h>
 
 #include <goffice/goffice.h>
-#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
@@ -86,9 +83,9 @@ wbcg_auto_complete_destroy (WBCGtk *wbcg)
  * wbcg_edit_finish:
  * @wbcg: #WBCGtk
  * @result: what should we do with the content
- * @showed_dialog: If non-NULL will indicate if a dialog was displayed.
+ * @showed_dialog: (optional) (out): indicates whether a dialog was displayed.
  *
- * Return: TRUE if editing completed successfully, or we were no editing.
+ * Returns: %TRUE if editing completed successfully, or we were no editing.
  **/
 gboolean
 wbcg_edit_finish (WBCGtk *wbcg, WBCEditResult result,
@@ -825,7 +822,7 @@ cb_warn_toggled (GtkToggleButton *button, gboolean *b)
  *  1) in-cell editing when you just start typing, and
  *  2) above sheet editing when you hit F2.
  *
- * Returns TRUE if we did indeed start editing.  Returns FALSE if the
+ * Returns: %TRUE if we did indeed start editing.  Returns %FALSE if the
  * cell-to-be-edited was locked.
  */
 gboolean
@@ -1144,7 +1141,7 @@ wbcg_set_entry (WBCGtk *wbcg, GnmExprEntry *entry)
  * wbcg_entry_has_logical:
  * @wbcg: #WBCGtk
  *
- * Returns: TRUE if wbcg_set_entry has redirected the edit_entry.
+ * Returns: %TRUE if wbcg_set_entry has redirected the edit_entry.
  **/
 gboolean
 wbcg_entry_has_logical (WBCGtk const *wbcg)
