@@ -1,4 +1,3 @@
-
 /*
  * xml-sax-write.c : export .gnumeric and the clipboard subset using the sax
  *			like wrappers in libgsf
@@ -30,7 +29,7 @@
 #include <workbook-view.h>
 #include <gnm-format.h>
 #include <workbook.h>
-#include <workbook-priv.h> /* Workbook::names */
+#include <workbook-priv.h>
 #include <cell.h>
 #include <sheet.h>
 #include <sheet-view.h>
@@ -743,7 +742,9 @@ xml_write_colrow_info (GnmColRowIter const *iter, closure_write_colrow *closure)
 					  closure->is_column);
 
 	closure->rle_count++;
-	if (NULL != iter && col_row_info_equal (prev, iter->cri))
+	if (NULL != iter &&
+	    iter->pos == closure->prev_pos + closure->rle_count &&
+	    col_row_info_equal (prev, iter->cri))
 		return FALSE;
 
 	if (closure->prev_pos != -1 && !col_row_info_equal (prev, def)) {
