@@ -1,6 +1,8 @@
-#!/usr/bin/python
+#!/usr/bin/python3 -B
 # -----------------------------------------------------------------------------
 
+import GnumericTest
+
 import gi
 gi.require_version('Gnm', '1.12')
 gi.require_version('GOffice', '0.10')
@@ -9,7 +11,7 @@ from gi.repository import GOffice
 Gnm.init()
 
 # A context for reporting errors to stderr
-cc = Gnm.CmdContextStderr.new ()
+cc = Gnm.CmdContextStderr()
 
 # Load plugins
 Gnm.plugins_init(cc)
