@@ -6,7 +6,7 @@ use lib ($0 =~ m|^(.*/)| ? $1 : ".");
 use GnumericTest;
 
 my $file = "Nelson.gnumeric";
-my $rle = 5;
+my $rle = 4.7;
 &message ("Check non-linear solver on $file problem.");
 &test_sheet_calc ("$samples/solver/$file", ['--solve'], "K39",
 		  sub {
