@@ -6,12 +6,12 @@ use lib ($0 =~ m|^(.*/)| ? $1 : ".");
 use GnumericTest;
 
 my $file = "Thurber.gnumeric";
-my $rle = 3.8;
+my $rle = 5;
 &message ("Check non-linear solver on $file problem.");
 &test_sheet_calc ("$samples/solver/$file", ['--solve'], "K39",
 		  sub {
 		      chomp;
 		      print STDERR "--> $_\n";
-		      return (/^[-+]?(\d|\.\d)/ &&
-			      $_ > $rle);
+		      my $ok = (/^[-+]?(\d|\.\d)/ && $_ > $rle);
+		      return $ok;
 		  });
